==> rendition-9.4.0.tgz: package/dist_esm5/components/Badge.js <==
import * as tslib_1 from "tslib";
import ColorHash from 'color-hash';
import assign from 'lodash/assign';
import memoize from 'lodash/memoize';
import * as React from 'react';
import styled from 'styled-components';
import asRendition from '../asRendition';
import { getColor, px } from '../utils';
import Txt from './Txt';
var colorHash = new ColorHash();
var backgroundColor = memoize(function (text) {
    return colorHash.hex(text.replace(/\s/g, ''));
});
var BaseBadge = styled(Txt)(templateObject_1 || (templateObject_1 = tslib_1.__makeTemplateObject(["\n\tborder-radius: ", ";\n\tdisplay: inline-block;\n\tmin-width: 40px;\n\ttext-align: center;\n\tfont-weight: 800;\n\tfont-style: normal;\n\tfont-stretch: normal;\n\tletter-spacing: 0.5px;\n"], ["\n\tborder-radius: ", ";\n\tdisplay: inline-block;\n\tmin-width: 40px;\n\ttext-align: center;\n\tfont-weight: 800;\n\tfont-style: normal;\n\tfont-stretch: normal;\n\tletter-spacing: 0.5px;\n"])), function (props) { return px(props.theme.radius); });
var Badge = function (_a) {
    var xsmall = _a.xsmall, small = _a.small, children = _a.children, theme = _a.theme, props = tslib_1.__rest(_a, ["xsmall", "small", "children", "theme"]);
    var fontSize = 2;
    if (small) {
        fontSize = 1;
    }
    if (xsmall) {
        fontSize = 10;
    }
    if (typeof children !== 'string') {
        throw new Error("The child element of the Badge component must be a string, received: " + typeof children);
    }
    return (React.createElement(BaseBadge, tslib_1.__assign({ p: "2px 5px", fontSize: fontSize }, props, { color: props.color || '#fff', bg: getColor(assign(props, { theme: theme }), 'bg', 'main') ||
            backgroundColor(children) }), children));
};
export default asRendition(Badge, [], ['bg', 'color']);
var templateObject_1;

==> rendition-11.10.0.tgz: package/dist_esm5/components/Badge.js <==
import * as tslib_1 from "tslib";
import ColorHash from 'color-hash';
import assign from 'lodash/assign';
import memoize from 'lodash/memoize';
import * as React from 'react';
import styled from 'styled-components';
import asRendition from '../asRendition';
import { getColor, isLight, px } from '../utils';
import Txt from './Txt';
var colorHash = new ColorHash();
var backgroundColor = memoize(function (text) {
    return colorHash.hex(text.replace(/\s/g, ''));
});
var BaseBadge = styled(Txt)(templateObject_1 || (templateObject_1 = tslib_1.__makeTemplateObject(["\n\tborder-radius: ", ";\n\tdisplay: inline-block;\n\tmin-width: 40px;\n\ttext-align: center;\n\tfont-weight: 800;\n\tfont-style: normal;\n\tfont-stretch: normal;\n\tletter-spacing: 0.5px;\n"], ["\n\tborder-radius: ", ";\n\tdisplay: inline-block;\n\tmin-width: 40px;\n\ttext-align: center;\n\tfont-weight: 800;\n\tfont-style: normal;\n\tfont-stretch: normal;\n\tletter-spacing: 0.5px;\n"])), function (props) { return px(props.theme.radius); });
var Badge = function (_a) {
    var xsmall = _a.xsmall, small = _a.small, children = _a.children, theme = _a.theme, props = tslib_1.__rest(_a, ["xsmall", "small", "children", "theme"]);
    var fontSize = 2;
    if (small) {
        fontSize = 1;
    }
    if (xsmall) {
        fontSize = 10;
    }
    if (typeof children !== 'string') {
        throw new Error("The child element of the Badge component must be a string, received: " + typeof children);
    }
    var bgColor = getColor(assign(props, { theme: theme }), 'bg', 'main') ||
        backgroundColor(children);
    return (React.createElement(BaseBadge, tslib_1.__assign({ p: "2px 5px", fontSize: fontSize }, props, { color: props.color || isLight(bgColor) ? 'text.main' : '#fff', bg: bgColor }), children));
};
export default asRendition(Badge, [], ['bg', 'color']);
var templateObject_1;
